Using the command line (cli)
============================

Open your command line shell to run commands:

.. code:: bash

   $ om
   Usage: om <command> [<action>] [<args>...] [options]
       om (models|datasets|scripts|jobs) [<args>...] [--replace] [--csv...] [options]
       om runtime [<args>...] [--async] [--result] [--param] [options]
       om cloud [<args>...] [options]
       om shell [<args>...] [options]
       om help [<command>]


See more examples and details in Guide:cli
